from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import (
    NUMBERS,
    OFF,
    ON,
    TRANSPARENT,
    XZPLANE,
    Boolean,
)
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class ViewportAnnotationOptions:
    """The ViewportAnnotationOptions object stores settings that control how annotations are rendered in a
    particular viewport. ViewportAnnotationOptions objects are accessed in one.

    of two ways:
    - The default viewport annotations. These settings are used as defaults when other
    **viewportAnnotationOptions** members are created and can be set to customize user
    preferences.
    - The viewport annotations associated with a particular viewport.
    The ViewportAnnotationOptions object has no constructor; Abaqus creates the
    **defaultViewportAnnotationOptions** member when a session is started. When a new viewport
    is created, the settings are copied from the current viewport.

    .. note::
        This object can be accessed by::

            session.defaultViewportAnnotationOptions
            session.viewports[name].viewportAnnotationOptions
    """

    @abaqus_method_doc
    def setValues(
        self,
        triad: Boolean = ON,
        triadPosition: int | None = None,
        triadColor: str = "",
        triadLabels: Literal[C.NUMBERS, C.LETTERS] = NUMBERS,
        triadFont: str = "",
        triadSize: int = 4,
        legend: Boolean = ON,
        legendMinMax: Boolean = OFF,
        legendBox: Boolean = ON,
        legendDecimalPlaces: int = 3,
        legendPosition: int | None = None,
        legendFont: str = "",
        legendTextColor: str = "",
        legendBackgroundStyle: Literal[C.OTHER, C.MATCH, C.TRANSPARENT] = TRANSPARENT,
        legendBackgroundColor: str = "",
        title: Boolean = ON,
        titleBox: Boolean = OFF,
        titlePosition: int | None = None,
        titleFont: str = "",
        titleTextColor: str = "",
        titleBackgroundStyle: Literal[C.OTHER, C.MATCH, C.TRANSPARENT] = TRANSPARENT,
        titleBackgroundColor: str = "",
        state: Boolean = ON,
        stateBox: Boolean = OFF,
        statePosition: int | None = None,
        stateFont: str = "",
        stateTextColor: str = "",
        stateBackgroundStyle: Literal[C.OTHER, C.MATCH, C.TRANSPARENT] = TRANSPARENT,
        stateBackgroundColor: str = "",
        compass: Boolean = ON,
        compassScale: float = 0,
        compassPrivilegedPlane: Literal[C.XYPLANE, C.YZPLANE, C.XZPLANE] = XZPLANE,
    ):
        """This method modifies the ViewportAnnotationOptions object.

        Parameters
        ----------
        triad
            A Boolean specifying whether the view orientation triad is shown. The default value is
            ON.
        triadPosition
            A pair of Ints specifying the position of the view orientation triad as a percentage of
            the viewport size. Possible values are (0, 0) ≤ **triadPosition** ≤ (100, 100). The
            default value is (6, 12).
        triadColor
            A String specifying the color of the view orientation triad. Possible values are any
            valid color. The default value is "White".
        triadLabels
            A SymbolicConstant specifying how the view orientation triad is labeled. Possible values
            are:NUMBERS, specifying the label axes 1, 2, 3.LETTERS, specifying the label axes X, Y,
            Z.The default value is NUMBERS.
        triadFont
            A String specifying the font of the view orientation triad labels. Possible values are
            any valid font. The default value is "-*-verdana-bold-r-normal--120-*".
        triadSize
            An Int specifying the length of each triad axis as a percentage of the viewport size.
            Possible values are 1 ≤ **legendDecimalPlaces** ≤ 50. The default value is 4.
        legend
            A Boolean specifying whether the legend is shown. The default value is ON.
        legendMinMax
            A Boolean specifying whether the minimum and maximum values for **X - Y** and contour plots
            are shown. The default value is OFF.
        legendBox
            A Boolean specifying whether the box around the legend is shown. The default value is
            ON.
        legendDecimalPlaces
            An Int specifying the number of decimal places to display in the legend. Possible values
            are 0 ≤ **legendDecimalPlaces** ≤ 9. The default value is 3.
        legendPosition
            A pair of Ints specifying the position of the legend as a percentage of the viewport
            size. Possible values are (0, 0)≤ **legendPosition** ≤ (100, 100). The default value is
            (2, 98).
        legendFont
            A String specifying the font of the legend labels. Possible values are any valid font.
            The default value is "-*-verdana-medium-r-*-*-*-120-*-*-*-*-iso8859-1".
        legendTextColor
            A String specifying the color of the legend. Possible values are any valid color. The
            default value is "White".
        legendBackgroundStyle
            A SymbolicConstant specifying the legend background style. Possible values are MATCH,
            TRANSPARENT, and OTHER. The default value is TRANSPARENT.The default color when OTHER is
            specified is the background color (black).
        legendBackgroundColor
            A String specifying the color of the legend background. Possible values are any valid
            color. The initial value matches the viewport background.
        title
            A Boolean specifying whether the title block is shown. The default value is ON.
        titleBox
            A Boolean specifying whether the box around the title block is shown. The default value
            is OFF.
        titlePosition
            A pair of Ints specifying the position of the title block as a percentage of the
            viewport size. Possible values are (0, 0) ≤ **titlePosition** ≤ (100, 100). The default
            value is (13, 20).
        titleFont
            A String specifying the font of the title. Possible values are any valid font. The
            default value is "-*-verdana-medium-r-*-*-*-120-*-*-*-*-iso8859-1".
        titleTextColor
            A String specifying the color of the title. Possible values are any valid color. The
            default value is "White".
        titleBackgroundStyle
            A SymbolicConstant specifying the title block background style. Possible values are
            MATCH, TRANSPARENT, and OTHER. The default value is TRANSPARENT.The default color when
            OTHER is specified is the background color (black).
        titleBackgroundColor
            A String specifying the color of the title block background. Possible values are any
            valid color. The initial value matches the viewport background.
        state
            A Boolean specifying whether the state block is shown. The default value is ON.
        stateBox
            A Boolean specifying whether the box around the state block is shown. The default value
            is OFF.
        statePosition
            A pair of Ints specifying the position of the state block as a percentage of the
            viewport size. Possible values are (0, 0) ≤ **statePosition** ≤ (100, 100). The default
            value is (13, 12).
        stateFont
            A String specifying the font of the state label. Possible values are any valid font. The
            default value is "-*-verdana-medium-r-*-*-*-120-*-*-*-*-iso8859-1".
        stateTextColor
            A String specifying the color of the state block label. Possible values are any valid
            color. The default value is "White".
        stateBackgroundStyle
            A SymbolicConstant specifying the state block background style. Possible values are
            MATCH, TRANSPARENT, and OTHER. The default value is TRANSPARENT.The default color when
            OTHER is specified is the background color (black).
        stateBackgroundColor
            A String specifying the color of the state block background. Possible values are any
            valid color. The initial value matches the viewport background.
        compass
            A Boolean specifying whether the 3D Compass is shown. The default value is ON.
        compassScale
            A Float specifying the relative size of the 3D Compass in the viewport. Possible values
            are 0.5 ≤ **compassScale** ≤ 2.0. The default value is 0.8.
        compassPrivilegedPlane
            A SymbolicConstant specifying the plane that will be used for the base of the 3D
            Compass. Possible values are XYPLANE, XZPLANE, and YZPLANE. The default value is
            XZPLANE.

        Raises
        ------
        RangeError
        """
        ...



from __future__ import annotations

from .AFXCommand import AFXCommand
from .AFXIntKeyword import AFXIntKeyword


class AFXSymConstKeyword(AFXIntKeyword):
    """This class is designed for the command keywords that have symbolic constant values."""

    def __init__(self, command: AFXCommand, name: str, isRequired: bool = False, defaultValue: int = 0):
        """Constructor.

        Parameters
        ----------
        command : AFXCommand
            Host command.
        name : str
            Keyword name.
        isRequired : bool
            True if the keyword is a required argument of the command.
        defaultValue : int
            Default value.
        """

    def getTypeName(self):
        """Returns the name of the keyword type.

        Reimplemented from AFXIntKeyword.
        """

    def getValueAsString(self):
        """Returns the text string that represents the keyword's current value.

        Reimplemented from AFXIntKeyword.
        """

    def setDefaultValue(self, defaultValue: int):
        """Sets the keyword's default value.

        Parameters
        ----------
        defaultValue : int
            Default value.
        """

    def setDefaultValueByString(self, defaultValueString: str):
        """Sets the keyword's default value (returns True if the given text string is valid).

        Parameters
        ----------
        defaultValueString : str
            Default value in text string form.
        """

    def setValue(self, newValue: int):
        """Sets the keyword's current value.

        Parameters
        ----------
        newValue : int
            New value.
        """

    def setValueByString(self, newValueString: str):
        """Sets the keyword's current value (returns True if the given text string is valid).

        Parameters
        ----------
        newValueString : str
            New value in text string form.
        """

    def setValueToDefault(self, ignoreUnspecified: bool = False):
        """Sets the keyword value to its default.

        Parameters
        ----------
        ignoreUnspecified : bool
            Ignore setting the value if the default is unspecified.
        """



from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ...UtilityAndView.abaqusConstants import (
    CENTROID,
    ENERGY,
    LINEAR,
    MAXIMUM,
    MODE_INDEPENDENT,
    MSFLD,
    NMORI,
    OFF,
    Boolean,
    SymbolicConstant,
)
from ...UtilityAndView.abaqusConstants import abaqusConstants as C
from .DamageEvolution import DamageEvolution
from .DamageStabilization import DamageStabilization
from .DamageStabilizationCohesive import DamageStabilizationCohesive


@abaqus_class_doc
class DamageInitiation:
    """The DamageInitiation object specifies material properties to define the initiation of damage.

    .. note::
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].ductileDamageInitiation
            mdb.models[name].materials[name].fldDamageInitiation
            mdb.models[name].materials[name].flsdDamageInitiation
            mdb.models[name].materials[name].hashinDamageInitiation
            mdb.models[name].materials[name].johnsonCookDamageInitiation
            mdb.models[name].materials[name].maxeDamageInitiation
            mdb.models[name].materials[name].maxpeDamageInitiation
            mdb.models[name].materials[name].maxpsDamageInitiation
            mdb.models[name].materials[name].maxsDamageInitiation
            mdb.models[name].materials[name].mkDamageInitiation
            mdb.models[name].materials[name].msfldDamageInitiation
            mdb.models[name].materials[name].quadeDamageInitiation
            mdb.models[name].materials[name].quadsDamageInitiation
            mdb.models[name].materials[name].shearDamageInitiation
            import odbMaterial
            session.odbs[name].materials[name].ductileDamageInitiation
            session.odbs[name].materials[name].fldDamageInitiation
            session.odbs[name].materials[name].flsdDamageInitiation
            session.odbs[name].materials[name].hashinDamageInitiation
            session.odbs[name].materials[name].johnsonCookDamageInitiation
            session.odbs[name].materials[name].maxeDamageInitiation
            session.odbs[name].materials[name].maxpeDamageInitiation
            session.odbs[name].materials[name].maxpsDamageInitiation
            session.odbs[name].materials[name].maxsDamageInitiation
            session.odbs[name].materials[name].mkDamageInitiation
            session.odbs[name].materials[name].msfldDamageInitiation
            session.odbs[name].materials[name].quadeDamageInitiation
            session.odbs[name].materials[name].quadsDamageInitiation
            session.odbs[name].materials[name].shearDamageInitiation

        The table data for this object are:

        - If constructor is DuctileDamageInitiation, the table data specify the following:

            - Equivalent fracture strain at damage initiation.
            - Stress triaxiality.
            - Strain rate.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor is FldDamageInitiation, the table data specify the following:

            - Major principal strain at damage initiation.
            - Minor principal strain.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor FlsdDamageInitiation, the table data specify the following:

            - Major principal stress at damage initiation.
            - Minor principal stress.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor is JohnsonCookDamageInitiation, the table data specify the following:

            - Johnson-Cook failure parameter D1.
            - Johnson-Cook failure parameter D2.
            - Johnson-Cook failure parameter D3.
            - Johnson-Cook failure parameter D4.
            - Johnson-Cook failure parameter D5.
            - Melting temperature.
            - Transition temperature.
            - Reference strain rate.
        - If constructor MkDamageInitiation, the table data specify the following:

            - Flaw size relative to nominal thickness of the section.
            - Angle (in degrees) with respect to the 1-direction of the local material orientation.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor is MsfldDamageInitiation and **definition** = MSFLD, the table data specify the following:

            - Nominal strain at damage initiation in a normal-only mode.
            - Equivalent Plastic strain at initiation of localized necking.
            - Ratio of minor to major principal strains.
            - Equivalent Plastic strain rate.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor is MsfldDamageInitiation and **definition** = FLD, the table data specify the following:

            - Major principal strain at initiation of localized necking.
            - Equivalent Plastic strain at initiation of localized necking.
            - Ratio of minor to major principal strains.
            - Equivalent Plastic strain rate.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor is QuadeDamageInitiation or MaxeDamageInitiation, the table data specify the following:

            - Nominal strain at damage initiation in a normal-only mode.
            - Nominal strain at damage initiation in a shear-only mode that involves separation only along the first shear direction.
            - Nominal strain at damage initiation in a shear-only mode that involves separation only along the second shear direction.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor is QuadsDamageInitiation or MaxsDamageInitiation, the table data specify the following:

            - Nominal strain at damage initiation in a normal-only mode.
            - Nominal strain at damage initiation in a shear-only mode that involves separation only along the first shear direction.
            - Nominal strain at damage initiation in a shear-only mode that involves separation only along the second shear direction.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor is MaxpeDamageInitiation, the table data specify the following:

            - Maximum principal strain at damage initiation.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor is MaxpsDamageInitiation, the table data specify the following:

            - Maximum principal stress at damage initiation.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor is ShearDamageInitiation, the table data specify the following:

            - Equivalent fracture strain at damage initiation.
            - Shear stress ratio.
            - Strain rate.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If constructor is HashinDamageInitiation, the table data specify the following:

            - Fiber tensile strength.
            - Fiber compressive strength.
            - Matrix tensile strength.
            - Matrix compressive strength.
            - Longitudinal shear strength.
            - Transverse shear strength.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.

        The corresponding analysis keywords are:

        - DAMAGE INITIATION
    """

    #: A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
    #: and MSFLD. The default value is MSFLD.
    definition: SymbolicConstant = MSFLD

    #: A Float specifying the critical value of the deformation severity index for equivalent
    #: Plastic strains. The default value is 10.0.
    feq: float = 10

    #: A Float specifying the critical value of the deformation severity index for strains
    #: normal to the groove direction. The default value is 10.0.
    fnn: float = 10

    #: A Float specifying the critical value of the deformation severity index for shear
    #: strains. The default value is 10.0.
    fnt: float = 10

    #: An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
    #: analysis is going to be performed. The default value is 1.
    frequency: int = 1

    #: A Float specifying the value of Ks. The default value is 0.0.
    ks: float = 0

    #: An Int specifying the number of imperfections to be considered for the evaluation of the
    #: Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
    #: the angular direction. The default value is 4.
    numberImperfections: int = 4

    #: A Boolean specifying whether the data depend on temperature. The default value is OFF.
    temperatureDependency: Boolean = OFF

    #: An Int specifying the number of field variable dependencies. The default value is 0.
    dependencies: int = 0

    #: A Float specifying the value of the coefficient that will multiply the shear
    #: contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
    alpha: float = 0

    #: A Float specifying the factor used for filtering the ratio of principal strain rates
    #: used for the evaluation of the MSFLD damage initiation criterion. The default value is
    #: 1.0.
    omega: float = 1

    #: A Float specifying the tolerance within which the damage initiation criterion must be
    #: satisfied. The default value is 0.05.
    tolerance: float = 0

    #: A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
    #: and TMORI. The default value is NMORI.
    direction: SymbolicConstant = NMORI

    #: A tuple of tuples of Floats specifying the items described in the "Table data" section.
    table: tuple[tuple[float, ...], ...] = ()

    #: A DamageEvolution object.
    damageEvolution: DamageEvolution | None = None

    #: A DamageStabilization object.
    damageStabilization: DamageStabilization | None = None

    #: A DamageStabilizationCohesive object.
    damageStabilizationCohesive: DamageStabilizationCohesive = DamageStabilizationCohesive()

    @abaqus_method_doc
    def DuctileDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].DuctileDamageInitiation
                session.odbs[name].materials[name].DuctileDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def FldDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].FldDamageInitiation
                session.odbs[name].materials[name].FldDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def FlsdDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].FlsdDamageInitiation
                session.odbs[name].materials[name].FlsdDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def JohnsonCookDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].JohnsonCookDamageInitiation
                session.odbs[name].materials[name].JohnsonCookDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def MaxeDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
        position: Literal[C.CRACKTIP, C.CENTROID, C.COMBINED] = CENTROID,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].MaxeDamageInitiation
                session.odbs[name].materials[name].MaxeDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.
        position
            An SymbolicConstant specifying the damage initiation position. Possible values are
            CENTROID, CRACKTIP and COMBINED. The default value is CENTROID.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def MaxsDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
        position: Literal[C.CRACKTIP, C.CENTROID, C.COMBINED] = CENTROID,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].MaxsDamageInitiation
                session.odbs[name].materials[name].MaxsDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.
        position
            An SymbolicConstant specifying the damage initiation position. Possible values are
            CENTROID, CRACKTIP and COMBINED. The default value is CENTROID.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def MkDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].MkDamageInitiation
                session.odbs[name].materials[name].MkDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def MsfldDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].MsfldDamageInitiation
                session.odbs[name].materials[name].MsfldDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def QuadeDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
        position: Literal[C.CRACKTIP, C.CENTROID, C.COMBINED] = CENTROID,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].QuadeDamageInitiation
                session.odbs[name].materials[name].QuadeDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.
        position
            An SymbolicConstant specifying the damage initiation position. Possible values are
            CENTROID, CRACKTIP and COMBINED. The default value is CENTROID.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def QuadsDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
        position: Literal[C.CRACKTIP, C.CENTROID, C.COMBINED] = CENTROID,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].QuadsDamageInitiation
                session.odbs[name].materials[name].QuadsDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.
        position
            An SymbolicConstant specifying the damage initiation position. Possible values are
            CENTROID, CRACKTIP and COMBINED. The default value is CENTROID.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def MaxpeDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
        position: Literal[C.CRACKTIP, C.CENTROID, C.COMBINED] = CENTROID,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].MaxpeDamageInitiation
                session.odbs[name].materials[name].MaxpeDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.
        position
            An SymbolicConstant specifying the damage initiation position. Possible values are
            CENTROID, CRACKTIP and COMBINED. The default value is CENTROID.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def MaxpsDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
        position: Literal[C.CRACKTIP, C.CENTROID, C.COMBINED] = CENTROID,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].MaxpsDamageInitiation
                session.odbs[name].materials[name].MaxpsDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.
        position
            An SymbolicConstant specifying the damage initiation position. Possible values are
            CENTROID, CRACKTIP and COMBINED. The default value is CENTROID.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def ShearDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].ShearDamageInitiation
                session.odbs[name].materials[name].ShearDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def HashinDamageInitiation(
        self,
        table: tuple,
        definition: Literal[C.FLD, C.MSFLD] = MSFLD,
        feq: float = 10,
        fnn: float = 10,
        fnt: float = 10,
        frequency: int = 1,
        ks: float = 0,
        numberImperfections: int = 4,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        alpha: float = 0,
        omega: float = 1,
        tolerance: float = 0,
        direction: Literal[C.NMORI, C.TMORI] = NMORI,
    ):
        """This method creates A DamageInitiation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].HashinDamageInitiation
                session.odbs[name].materials[name].HashinDamageInitiation

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described in the "Table data"
            section.
        definition
            A SymbolicConstant specifying the damage initiation definition. Possible values are FLD
            and MSFLD. The default value is MSFLD.
        feq
            A Float specifying the critical value of the deformation severity index for equivalent
            Plastic strains. The default value is 10.0.
        fnn
            A Float specifying the critical value of the deformation severity index for strains
            normal to the groove direction. The default value is 10.0.
        fnt
            A Float specifying the critical value of the deformation severity index for shear
            strains. The default value is 10.0.
        frequency
            An Int specifying the frequency, in increments, at which the Marciniak-Kuczynski
            analysis is going to be performed. The default value is 1.
        ks
            A Float specifying the value of Ks. The default value is 0.0.
        numberImperfections
            An Int specifying the number of imperfections to be considered for the evaluation of the
            Marciniak-Kuczynski analysis. These imperfections are assumed to be equally spaced in
            the angular direction. The default value is 4.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        alpha
            A Float specifying the value of the coefficient that will multiply the shear
            contribution to the Hashin's fiber initiation criterion. The default value is 0.0.
        omega
            A Float specifying the factor used for filtering the ratio of principal strain rates
            used for the evaluation of the MSFLD damage initiation criterion. The default value is
            1.0.
        tolerance
            A Float specifying the tolerance within which the damage initiation criterion must be
            satisfied. The default value is 0.05.
        direction
            A SymbolicConstant specifying the damage initiation direction. Possible values are NMORI
            and TMORI. The default value is NMORI.

        Returns
        -------
        DamageInitiation
            A DamageInitiation object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the DamageInitiation object."""
        ...

    @abaqus_method_doc
    def DamageEvolution(
        self,
        type: Literal[C.DISPLACEMENT, C.ENERGY],
        table: tuple,
        degradation: Literal[C.MAXIMUM, C.MULTIPLICATIVE] = MAXIMUM,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        mixedModeBehavior: Literal[C.MODE_INDEPENDENT, C.TABULAR, C.POWER_LAW, C.BK] = MODE_INDEPENDENT,
        modeMixRatio: Literal[C.TRACTION, C.ENERGY] = ENERGY,
        power: float | None = None,
        softening: Literal[C.LINEAR, C.EXPONENTIAL, C.TABULAR] = LINEAR,
    ) -> DamageEvolution:
        """This method creates a DamageEvolution object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].ductileDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].fldDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].flsdDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].hashinDamageInitiation.DamageEvolution.DamageEvolutione].materials[name].johnsonCookDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].maxeDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].maxpeDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].maxpsDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].maxsDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].mkDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].msfldDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].quadeDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].quadsDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].shearDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].ductileDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].fldDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].flsdDamageInitiation.DamageEvolution.DamageEvolutioname].materials[name].hashinDamageInitiation.DamageEvolution.DamageEvolutioname].materials[name].johnsonCookDamageInitiation.DamageEvolution.DamageEvolutioname].materials[name].maxeDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].maxpeDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].maxpsDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].maxsDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].mkDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].msfldDamageInitiation.DamageEvolution.DamageEvolutioname].materials[name].quadeDamageInitiation.DamageEvolution.DamageEvolutioname].materials[name].quadsDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].shearDamageInitiation.DamageEvolution

        Parameters
        ----------
        type
            A SymbolicConstant specifying the type of damage evolution. Possible values are
            DISPLACEMENT and ENERGY.
        table
            A sequence of sequences of Floats specifying the items described below.
        degradation
            A SymbolicConstant specifying the degradation. Possible values are MAXIMUM and
            MULTIPLICATIVE. The default value is MAXIMUM.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        mixedModeBehavior
            A SymbolicConstant specifying the mixed mode behavior. Possible values are
            MODE_INDEPENDENT, TABULAR, POWER_LAW, and BK. The default value is MODE_INDEPENDENT.
        modeMixRatio
            A SymbolicConstant specifying the mode mix ratio. Possible values are ENERGY and
            TRACTION. The default value is ENERGY.
        power
            None or a Float specifying the exponent in the power law or the Benzeggagh-Kenane
            criterion that defines the variation of fracture energy with mode mix for cohesive
            elements. The default value is None.
        softening
            A SymbolicConstant specifying the softening. Possible values are LINEAR, EXPONENTIAL,
            and TABULAR. The default value is LINEAR.

        Returns
        -------
        DamageEvolution
            A DamageEvolution object.

        Raises
        ------
        RangeError
        """
        return DamageEvolution(
            type=type,
            table=table,
            degradation=degradation,
            temperatureDependency=temperatureDependency,
            dependencies=dependencies,
            mixedModeBehavior=mixedModeBehavior,
            modeMixRatio=modeMixRatio,
            power=power,
            softening=softening,
        )

    @abaqus_method_doc
    def DamageStabilizationCohesive(self, cohesiveCoeff: float | None = None) -> DamageStabilizationCohesive:
        """This method creates a DamageStabilizationCohesive object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].ductileDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].fldDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].flsdDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].hashinDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].johnsonCookDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].maxeDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].maxpeDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].maxpsDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].maxsDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].mkDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].msfldDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].quadeDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].quadsDamageInitiation.DamageStabilizationCohesive
                mdb.models[name].materials[name].shearDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].ductileDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].fldDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].flsdDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].hashinDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].johnsonCookDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].maxeDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].maxpeDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].maxpsDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].maxsDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].mkDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].msfldDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].quadeDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].quadsDamageInitiation.DamageStabilizationCohesive
                session.odbs[name].materials[name].shearDamageInitiation.DamageStabilizationCohesive

        Parameters
        ----------
        cohesiveCoeff
            None or a Float specifying the viscosity coefficient. The default value is None.

        Returns
        -------
        DamageStabilizationCohesive
            A DamageStabilizationCohesive object.

        Raises
        ------
        RangeError
        """
        return DamageStabilizationCohesive(cohesiveCoeff=cohesiveCoeff)



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc

from .CompositeDampingComponentArray import CompositeDampingComponentArray


@abaqus_class_doc
class CompositeDamping:
    """A CompositeDamping object contains composite modal damping parameters.

    .. note::
        This object can be accessed by::

            import step
            mdb.models[name].steps[name].compositeDamping
    """

    #: A CompositeDampingComponentArray object.
    components: CompositeDampingComponentArray = []



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc

from ..UtilityAndView.abaqusConstants import (
    ELEMENT,
    EXTERIOR,
    HOLLOW_CIRCLE,
    MEDIUM,
    OFF,
    ON,
    SHADED,
    SMALL,
    SOLID,
    VERY_THIN,
    WIRE,
    Boolean,
    SymbolicConstant,
)


@abaqus_class_doc
class DGCommonOptions:
    """The DGCommonOptions object stores values and attributes that are common to all plot
    states. The DGCommonOptions object has no constructor command. Abaqus creates an
    *odbDisplayOptions.commonOptions* member when a display group instance is created, using
    values from *odbDisplay.commonOptions*.

    .. note::
        This object can be accessed by::

            session.viewports[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.commonOptions
            session.viewports[name].layers[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.commonOptions
            session.viewports[name].layers[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.commonOptions
            session.viewports[name].layers[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.commonOptions
            session.viewports[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.commonOptions
            session.viewports[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.commonOptions
    """

    #: A SymbolicConstant specifying the render style of the plot. Possible values are
    #: WIREFRAME, FILLED, HIDDEN, and SHADED. The default value is SHADED.
    renderStyle: SymbolicConstant = SHADED

    #: A SymbolicConstant specifying which edges to plot. Possible values are ALL, EXTERIOR,
    #: FEATURE, FREE, and NONE. The default value is EXTERIOR.NONE can be used only when
    #: **renderStyle** = SHADED.
    visibleEdges: SymbolicConstant = EXTERIOR

    #: A SymbolicConstant specifying the edge line style. Possible values are SOLID, DASHED,
    #: DOTTED, and DOT_DASH. The default value is SOLID.
    edgeLineStyle: SymbolicConstant = SOLID

    #: A SymbolicConstant specifying the edge line thickness. Possible values are VERY_THIN,
    #: THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    edgeLineThickness: SymbolicConstant = VERY_THIN

    #: A Boolean specifying whether to allow color coded items in the output database to
    #: override the edge and fill color settings. The default value is ON.
    colorCodeOverride: Boolean = ON

    #: A Boolean specifying whether to plot the element labels. The default value is OFF.
    elemLabels: Boolean = OFF

    #: A Boolean specifying whether to plot the face labels. The default value is OFF.
    faceLabels: Boolean = OFF

    #: A Boolean specifying whether to plot the node labels. The default value is OFF.
    nodeLabels: Boolean = OFF

    #: A Boolean specifying whether to plot the node symbols. The default value is OFF.
    nodeSymbols: Boolean = OFF

    #: A SymbolicConstant specifying the node symbol types. Possible values
    #: are:FILLED_CIRCLEFILLED_SQUAREFILLED_DIAMONDFILLED_TRIHOLLOW_CIRCLEHOLLOW_SQUAREHOLLOW_DIAMONDHOLLOW_TRICROSSXMARKERThe
    #: default value is HOLLOW_CIRCLE.
    nodeSymbolType: SymbolicConstant = HOLLOW_CIRCLE

    #: A SymbolicConstant specifying the node symbol size. Possible values are SMALL, MEDIUM,
    #: and LARGE. The default value is SMALL.
    nodeSymbolSize: SymbolicConstant = SMALL

    #: A Boolean specifying whether elements are displayed in a shrunk format. The default
    #: value is OFF.
    elementShrink: Boolean = OFF

    #: An Int specifying the percentage to shrink the elements when **elementShrink** = ON.
    #: Possible values are 0≤ **elementShrinkPercentage** ≤ 90. The default value is 5.
    elementShrinkFactor: int = 5

    #: A Boolean specifying whether to scale coordinates. The default value is OFF.
    coordinateScale: Boolean = OFF

    #: A Boolean specifying whether to draw arrows that indicate the directions of element and
    #: surface normals. The default value is OFF.
    normals: Boolean = OFF

    #: A SymbolicConstant specifying whether to draw element normals or surface normals.
    #: Possible values are ELEMENT and SURFACE. The default value is ELEMENT.
    normalDisplay: SymbolicConstant = ELEMENT

    #: A SymbolicConstant specifying the length of the normal arrows. Possible values are
    #: SHORT, MEDIUM, and LONG. The default value is MEDIUM.
    normalArrowLength: SymbolicConstant = MEDIUM

    #: A SymbolicConstant specifying the thickness of the normal arrows. Possible values are
    #: VERY_THIN, THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    normalLineThickness: SymbolicConstant = VERY_THIN

    #: A SymbolicConstant specifying the arrowhead style of the normal arrows. Possible values
    #: are NONE, FILLED, and WIRE. The default value is WIRE.
    normalArrowheadStyle: SymbolicConstant = WIRE

    #: A Boolean specifying whether to set translucency. The default value is OFF.
    translucency: Boolean = OFF

    #: A Float specifying the translucency factor when **translucency** = ON. Possible values are
    #: 0.0≤ **translucencyFactor** ≤ 1.0. The default value is 0.3.
    translucencyFactor: float = 0

    #: A String specifying the color to be used to plot the edges of the model when
    #: **renderStyle** = WIREFRAME or HIDDEN. The default value is "White".
    edgeColorWireHide: str = ""

    #: A String specifying the color to be used to plot the edges of the model when
    #: **renderStyle** = FILLED or SHADED. The default value is "Black".
    edgeColorFillShade: str = ""

    #: A String specifying the color to be used to fill elements when **renderStyle** = FILLED or
    #: SHADED. The default value is "White".
    fillColor: str = ""

    #: A String specifying the label font to be used for all model labels. The default value is
    #: "-*-courier-medium-r-normal-*-*-120-*-*-m-*-*-*".
    labelFont: str = ""

    #: A String specifying the color to be used to plot the element labels. The default value
    #: is "Cyan".
    elemLabelColor: str = ""

    #: A String specifying the color to be used to plot the face labels. The default value is
    #: "Red".
    faceLabelColor: str = ""

    #: A String specifying the color to be used to plot the node labels. The default value is
    #: "Yellow".
    nodeLabelColor: str = ""

    #: A String specifying the color to be used to plot the node symbols. The default value is
    #: "Yellow".
    nodeSymbolColor: str = ""

    #: A String specifying the color to be used to plot the normal to a nonbeam element or to a
    #: surface. The default value is "Red".
    faceNormalColor: str = ""

    #: A String specifying the color to be used to plot an arrow along the beam n1n1-direction.
    #: The default value is "Blue".
    beamN1Color: str = ""

    #: A String specifying the color to be used to plot an arrow along the beam n2n2-direction.
    #: The default value is "Red".
    beamN2Color: str = ""

    #: A String specifying the color to be used to plot an arrow along the tangent to a beam.
    #: The default value is "White".
    beamTangentColor: str = ""

    #: A tuple of three Floats specifying the coordinate scaling in each of the three
    #: coordinate directions when **coordinateScale** = ON. The default value is (1, 1, 1).
    coordinateScaleFactors: float | None = None



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class AutoColors:
    """The AutoColors object defines a color palette.

    .. note::
        This object can be accessed by::

            session.autoColors
    """

    @abaqus_method_doc
    def setValues(self, colors: tuple):
        """This method changes the color palette.

        Parameters
        ----------
        colors
            A sequence of Strings specifying the colors of the palette. Strings must be named colors
            or represent red, green, blue components in hexadecimal form. For instance, '#FF0000'
            for red, '#00FF00' for green and '#0000FF' for blue
        """
        ...



from __future__ import annotations

from .FXMenuCaption import FXMenuCaption


class FXMenuCascade(FXMenuCaption):
    """The cascade menu widget is used to bring up a sub menu from a pull down menu."""



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Model.ModelBase import ModelBase
from ..UtilityAndView.abaqusConstants import Boolean
from .PartInstance import PartInstance


@abaqus_class_doc
class AssemblyModel(ModelBase):
    """Abaqus creates a Model object named `Model-1` when a session is started.

    .. note::
        This object can be accessed by::

            mdb.models[name]
    """

    @abaqus_method_doc
    def Instance(self, name: str, objectToCopy: PartInstance):
        """This method copies a PartInstance object from the specified model and creates a new PartInstance
        object.

        .. note::
            This function can be accessed by::

                mdb.models[name].Instance

        Parameters
        ----------
        name
            A String specifying the repository key.
        objectToCopy
            A PartInstance object to be copied.

        Returns
        -------
        Model
            A Model object.
        """
        return self

    @abaqus_method_doc
    def convertAllSketches(self, regenerate: Boolean = True, convertReversedSketches: Boolean = True):
        """This method converts all sketches from Abaqus 6.5 or earlier to the equivalent ConstrainedSketch
        objects.

        Parameters
        ----------
        regenerate
            A Boolean specifying if all the features in assembly as well as in all the parts in the
            model should be regenerated after the conversion. The default value is True.
        convertReversedSketches
            A Boolean specifying whether sketches in analytic rigid parts should be converted even
            if they cause the orientation of surfaces defined on them to be flipped. The default
            value is True.

        Returns
        -------
        list[str]
            A list of strings describing any warnings or errors encountered during the conversion
            process.
        """
        ...

    @abaqus_method_doc
    def linkInstances(self, instancesMap: tuple):
        """This method links the selected PartInstance objects to the corresponding PartInstance objects from
        the specified models. If all instances of a Part are selected for linking, the Part will be linked as
        well. If not, a new linked child Part object will be created and added to the repository.

        Parameters
        ----------
        instancesMap
            A tuple of tuples containing the instance name to be linked and the corresponding
            PartInstance object to which it will be linked.

        Returns
        -------
        list[str]
            A list of strings describing any warnings or errors encountered during the conversion
            process.
        """
        ...



from __future__ import annotations

from .AFXMode import AFXMode
from .FXObject import FXObject


class AFXCommand(FXObject):
    """This class is the abstract base class for command classes that are processed by modes."""

    def __init__(self, mode: AFXMode, method: str, objectName: str = "''", registerQuery: bool = False):
        """Constructor.

        Parameters
        ----------
        mode : AFXMode
            Host mode.
        method : str
            Method.
        objectName : str
            Object name.
        registerQuery : bool
            True if a query should be registered when the command is used for the GUI.
        """

    def activate(self):
        """Activates the command; active commands will be processed during command generation."""

    def deactivate(self):
        """Deactivates the command; inactive commands will not be processed during command generation."""

    def getCommandString(self):
        """Returns the command string based on the current values of the active keywords."""

    def getExpandedObjectName(self):
        """Returns the expanded object name that has all the "%s"'s replaced by the current names."""

    def getKeyword(self, index: int):
        """Returns the keyword at the given index (returns 0 if the index is out-of-bounds).

        Parameters
        ----------
        index : int
            Keyword index (0-based).
        """

    def getMethod(self):
        """Returns the command's method."""

    def getNumKeywords(self):
        """Returns the number of keywords."""

    def getObjectName(self):
        """Returns the object name (which is not expanded and may include "%s"'s)."""

    def isActive(self):
        """Returns True if the command is active."""

    def isQueryNeeded(self):
        """Returns True if the command needs to register a query for kernel state."""

    def isRequired(self):
        """Returns True if this command is going to be sent even if none of its keywords has been modified,
        otherwise returns False."""

    def setKeywordValuesToDefaults(self, ignoreUnspecified: bool = False):
        """Sets the values of all keywords to their defaults.

        Parameters
        ----------
        ignoreUnspecified : bool
            Ignore setting the value if the default is unspecified.
        """

    def setKeywordValuesToPrevious(self):
        """Sets the values of all keywords to their previous values."""

    def setMethod(self, method: str):
        """Sets the command's method.

        Parameters
        ----------
        method : str
            Method.
        """

    def setObjectName(self, objectName: str):
        """Sets the object name.

        Parameters
        ----------
        objectName : str
            Object name.
        """

    def setRequired(self, val: bool):
        """Sets this command as required or optional; if True the command will always be sent, if False the
        command will be sent only if it has modified keywords or if it has no keywords.

        Parameters
        ----------
        val : bool
        """

    def syncKeywordPreviousValues(self):
        """Synchronizes the current values and previous values of all keywords."""

    def verify(self):
        """Throws an exception if any of the keywords contain invalid data."""



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .Profile import Profile


@abaqus_class_doc
class ArbitraryProfile(Profile):
    """The ArbitraryProfile object defines the properties of an arbitrary profile. The ArbitraryProfile object
    is derived from the Profile object.

    .. note::
        This object can be accessed by::

            import section
            mdb.models[name].profiles[name]
            import odbSection
            session.odbs[name].profiles[name]

        The table data for this object are:
        The first sequence in the table specifies the following:

        - 1-coordinate of the first point defining the profile.
        - 2-coordinate of the first point defining the profile.

        All other sequences in the table specify the following:

        - 1-coordinate of the next point defining the profile.
        - 2-coordinate of the next point defining the profile.
        - The thickness of the segment ending at that point.

        The corresponding analysis keywords are:

        - BEAM SECTION
    """

    #: A String specifying the repository key.
    name: str

    #: A sequence of sequences of Floats specifying the items described below.
    table: tuple[tuple[float, ...], ...] = ()

    @abaqus_method_doc
    def __init__(self, name: str, table: tuple):
        """This method creates a ArbitraryProfile object.

        .. note::
            This function can be accessed by::

                mdb.models[name].ArbitraryProfile
                session.odbs[name].ArbitraryProfile

        Parameters
        ----------
        name
            A String specifying the repository key.
        table
            A sequence of sequences of Floats specifying the items described below.

        Returns
        -------
        ArbitraryProfile
            An ArbitraryProfile object.

        Raises
        ------
        RangeError
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the ArbitraryProfile object.

        Raises
        ------
        RangeError
        """
        ...



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Region.Region import Region
from .IMAField import IMAField


@abaqus_class_doc
class PredefinedField:
    """The PredefinedField object is the base object for the objects in the predefined field repository. The
    methods and members of the PredefinedField object are common to all objects derived from PredefinedField. An
    instance of any PredefinedField object can be obtained through the predefined field repository of the Model
    object. An instance of any PredefinedFieldState object can be obtained through the predefined field
    repository of the Step object.

    .. note::
        This object can be accessed by::

            import load
            mdb.models[name].predefinedFields[name]
    """

    #: A String specifying the repository key.
    name: str = ""

    #: A Region object specifying the region to which the predefined field is applied. **Region**
    #: is ignored if the predefined field has an **instances** member available. **Region** is also
    #: ignored if the predefined field has a **distributionType** member available, and
    #: **distributionType** = FROM_FILE or FROM_FILE_AND_USER_DEFINED.
    region: Region = Region()

    #: An IMAField for MaterialAssignment predefined field。
    fieldList: IMAField = IMAField()

    @abaqus_method_doc
    def move(self, fromStepName: str, toStepName: str):
        """This method moves a specific PredefinedFieldState object from one step to a different step.

        Parameters
        ----------
        fromStepName
            A String specifying the name of the step from which the PredefinedFieldState object is
            moved.
        toStepName
            A String specifying the name of the step to which the PredefinedFieldState object is
            moved.

        Raises
        ------
        TextError
        """
        ...

    @abaqus_method_doc
    def resume(self):
        """This method resumes the predefined field that was previously suppressed."""
        ...

    @abaqus_method_doc
    def suppress(self):
        """This method suppresses the predefined field."""
        ...

    @abaqus_method_doc
    def delete(self, indices: tuple):
        """This method allows you to delete existing fields.

        Parameters
        ----------
        indices
            A sequence of Ints specifying the index of each field to delete.
        """
        ...



from __future__ import annotations

from abaqus import session
from abaqus.Odb.OdbCommands import (
    AnalyticSurfaceProfile,
    isUpgradeRequiredForOdb,
    maxEnvelope,
    minEnvelope,
    openOdb,
    upgradeOdb,
)
from abaqus.Property.PlyStackPlot import OdbPlyStackPlot
from abaqusConstants import *

session.Viewport(name="Viewport: 1")

__all__ = [
    "session",
    "isUpgradeRequiredForOdb",
    "maxEnvelope",
    "minEnvelope",
    "openOdb",
    "upgradeOdb",
    "AnalyticSurfaceProfile",
    "OdbPlyStackPlot",
]



from __future__ import annotations

from .constants import DEFAULT_PAD
from .FXComposite import FXComposite
from .FXIcon import FXIcon
from .FXLabel import FXLabel
from .FXObject import FXObject

#: Button is up.
STATE_UP: int = hash("STATE_UP")

#: Button is down.
STATE_DOWN: int = hash("STATE_DOWN")

#: Button is engaged.
STATE_ENGAGED: int = hash("STATE_ENGAGED")

#: Same as STATE_UP (used for check buttons or radio buttons).
STATE_UNCHECKED: int = hash("STATE_UNCHECKED")

#: Same as STATE_ENGAGED (used for check buttons or radio buttons).
STATE_CHECKED: int = hash("STATE_CHECKED")

#: Automatically gray out when not updated.
BUTTON_AUTOGRAY: int = hash("BUTTON_AUTOGRAY")

#: Automatically hide button when not updated.
BUTTON_AUTOHIDE: int = hash("BUTTON_AUTOHIDE")

#: Toolbar style button \[flat look\].
BUTTON_TOOLBAR: int = hash("BUTTON_TOOLBAR")

#: May become default button when receiving focus.
BUTTON_DEFAULT: int = hash("BUTTON_DEFAULT")

#: This button is the initial default button.
BUTTON_INITIAL: int = hash("BUTTON_INITIAL")

#: Normal button style.
BUTTON_NORMAL: int = hash("BUTTON_NORMAL")


class FXButton(FXLabel):
    """A button provides a push button, with optional icon and/or text label.

    When pressed, the button widget sends a SEL_COMMAND to its target.
    """

    def __init__(
        self,
        p: FXComposite,
        text: str,
        ic: FXIcon | None = None,
        tgt: FXObject | None = None,
        sel: int = 0,
        opts: int = BUTTON_NORMAL,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_PAD,
        pr: int = DEFAULT_PAD,
        pt: int = DEFAULT_PAD,
        pb: int = DEFAULT_PAD,
    ):
        """Construct button with text and icon.

        Parameters
        ----------
        p : FXComposite

        text : str

        ic : FXIcon | None

        tgt : FXObject | None

        sel : int

        opts : int

        x : int

        y : int

        w : int

        h : int

        pl : int

        pr : int

        pt : int

        pb : int
        """

    def canFocus(self):
        """Returns True because a button can receive focus.

        Reimplemented from FXWindow. Reimplemented in AFXFlyoutItem.
        """

    def getButtonStyle(self):
        """Get the button style flags."""

    def getState(self):
        """Get the button state."""

    def setButtonStyle(self, style: int):
        """Set the button style flags.

        Parameters
        ----------
        style : int
        """

    def setDefault(self, enable: bool = True):
        """Set as default button. Reimplemented from FXWindow.

        Parameters
        ----------
        enable : bool
        """

    def setState(self, s: int):
        """Set the button state.

        Parameters
        ----------
        s : int
        """



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc

from ..UtilityAndView.abaqusConstants import SymbolicConstant
from .InteractionState import InteractionState


@abaqus_class_doc
class PressurePenetrationState(InteractionState):
    """The PressurePenetrationState object stores the propagating data of a PressurePenetration object in a
    step. One instance of this object is created internally by the PressurePenetration object for each step. The
    instance is also deleted internally by the PressurePenetration object. The PressurePenetrationState object
    has no constructor or methods. The PressurePenetrationState object is derived from the InteractionState
    object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

        The corresponding analysis keywords are:

        - PRESSURE PENETRATION
    """

    #: A Float specifying the fraction of the current step time over which the fluid pressure
    #: on newly penetrated contact surface segments is ramped up to the current magnitude. The
    #: default value is 10⁻³.
    penetrationTime: float | None = None

    #: A SymbolicConstant specifying the propagation state of the **penetrationTime** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    penetrationTimeState: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the **criticalPressure** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    criticalPressureState: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the **penetrationPressure** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    penetrationPressureState: SymbolicConstant

    #: A tuple of Floats specifying the fluid pressure magnitude. For steady state dynamic
    #: analyses, a tuple of Complexes specifying the fluid pressure magnitude.
    penetrationPressure: tuple[float, ...] = ()

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""

    #: A tuple of Floats specifying the critical contact pressure below which fluid penetration
    #: starts to occur.
    criticalPressure: tuple[float, ...] = ()

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class Hysteresis:
    """The Hysteresis object specifies the creep part of the material model for the hysteretic behavior of
    elastomers.

    .. note::
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].hyperelastic.hysteresis
            import odbMaterial
            session.odbs[name].materials[name].hyperelastic.hysteresis

        The table data for this object are:

        - Stress scaling factor.
        - Creep parameter.
        - Effective stress exponent.
        - Creep strain exponent.

        The corresponding analysis keywords are:

        - HYSTERESIS
    """

    @abaqus_method_doc
    def __init__(self, table: tuple):
        """This method creates a Hysteresis object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].hyperelastic.Hysteresis
                session.odbs[name].materials[name].hyperelastic.Hysteresis

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.

        Returns
        -------
        Hysteresis
            A Hysteresis object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Hysteresis object.

        Raises
        ------
        RangeError
        """
        ...



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc


@abaqus_class_doc
class DirectDampingComponent:
    """A DirectDampingComponent object is used to define direct damping over a range of modes.

    .. note::
        This object can be accessed by::

            import step
            mdb.models[name].steps[name].directDamping.components[i]
    """

    #: An Int specifying the mode number of the lowest mode of a range.
    start: int | None = None

    #: An Int specifying the mode number of the highest mode of a range.
    end: int | None = None

    #: A Float specifying the fraction of critical damping.
    fraction: float | None = None



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc

from .OdbAuxiliaryData import OdbAuxiliaryData


@abaqus_class_doc
class OdbAnalysisError:
    """The OdbAnalysisError object stores the description of different errors encountered during the analysis.

    .. note::
        This object can be accessed by::

            import visualization
            session.odbData[name].diagnosticData.analysisErrors[i]
    """

    #: An int specifying the increment number where the analysis was aborted. This attribute is
    #: read-only.
    incrementNumber: str = ""

    #: An int specifying the iteration number where the analysis was aborted. This attribute is
    #: read-only.
    iterationNumber: str = ""

    #: An int specifying the attempt number on which the analysis was aborted. This attribute
    #: is read-only.
    attemptNumber: str = ""

    #: String specifying the category of error. This attribute is read-only.
    category: str = ""

    #: An OdbAuxiliaryData object.
    data: OdbAuxiliaryData = OdbAuxiliaryData()

    #: String specifying the cause of the error. This attribute is read-only.
    description: str = ""

    #: String specifying the exact nature of the problem. This attribute is read-only.
    detailStrings: str = ""

    #: String specifying the exact reason for the error encountered. This attribute is
    #: read-only.
    knowledgeItem: str = ""

    #: An int specifying the number of variations. This attribute is read-only.
    numberOfVariations: str = ""

    #: An int specifying the step number on which the error was encountered. This attribute is
    #: read-only.
    stepNumber: str = ""
